Documentation
¶
Index ¶
Constants ¶
const DEFAULT_CAPACITY uint = 1 << 16 /* 256 KiB / sizeof(uint32) */
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Filter ¶
type Filter []uint32
func NewFilter ¶
Create a new filter with the given number of 32-bit blocks.
If capacity is set to 0, the default capacity of 64k (=256 KiB) is used.
func (Filter) MayContain ¶
Check the filter for an element.
If the method returns `true`, the element may be present in the filter. Otherwise, it is guaranteed not to be in the filter.
Click to show internal directories.
Click to hide internal directories.